@@ -397,6 +397,7 @@ PorseleinApp.standbyOff = function ()
 
 
 //Motion sensor
+PorseleinApp.motionSensitivity = 2
 PorseleinApp.ax_cache = 0
 PorseleinApp.ay_cache = 0
 PorseleinApp.az_cache = 0
@@ -424,7 +425,7 @@ PorseleinApp.standbyOffByMotion = function (event)
     PorseleinApp.ay_cache = ay;
     PorseleinApp.az_cache = az;
     
-    if (Math.abs(xdiff) > 1 || Math.abs(ydiff) > 1 || Math.abs(zdiff) > 1)
+    if (Math.abs(xdiff) > PorseleinApp.motionSensitivity || Math.abs(ydiff) > PorseleinApp.motionSensitivity || Math.abs(zdiff) > PorseleinApp.motionSensitivity)
     {
         PorseleinApp.motions++;
         if(PorseleinApp.motions > 2)
